============
unreferenced
============

Reports unreferenced files.


Installation
============

To install *unreferenced*::

   $ pip install unreferenced


Usage
=====

::

   $ unreferenced .
   ./junk.py
   ./unused.png
